@@ -1,6 +1,5 @@
 from django.conf import settings
 from drf_yasg.generators import OpenAPISchemaGenerator
-from rest_framework import serializers
 
 
 class Enums:
@@ -45,45 +44,22 @@ class Constants:
     FORMAT_DATE_TIME_TIMEZONE_EN = '%Y-%m-%dT%H:%M:%S.%fZ'
     EXPIRED = 'EXPIRADO'
     INVALID = 'INVALIDO'
+    REFRESH_TOKEN = 'REFRESH_TOKEN'
+    ACCESS_TOKEN = 'ACCESS_TOKEN'
     PHOTO_DEFAULT = '3fa85f64-5717-4562-b3fc-2c963f66afa6'
+    FRONTEND_CONTEXT = 'davinci'
     WINDOWS = 'win'
     LINUX = 'linux'
     MACOS = 'mac'
+    DEVELOP = 'dev'
+    DEPLOY = 'dep'
+    LOCAL = 'loc'
 
 
 class FrontendUrl:
     URL_BASE_COMMUNITY = '/usuarios/comunidad/'
 
 
-class DynamicFieldsSerializer(serializers.ModelSerializer):
-    def __init__(self, *args, **kwargs):
-        fields = kwargs.pop('fields', None)
-        notfields = kwargs.pop('notfields', None)
-
-        super(DynamicFieldsSerializer, self).__init__(*args, **kwargs)
-
-        if fields is not None:
-            existing = set(self.fields.keys())
-            if not isinstance(fields, str):
-                allowed = set(fields)
-                for field_name in existing - allowed:
-                    self.fields.pop(field_name)
-            else:
-                for field_name in existing:
-                    if field_name != fields:
-                        self.fields.pop(field_name)
-
-        elif notfields is not None:
-            existing = set(self.fields.keys())
-            if not isinstance(notfields, str):
-                disallowed = set(notfields)
-                for field_name in disallowed:
-                    if field_name in existing:
-                        self.fields.pop(field_name)
-            else:
-                self.fields.pop(notfields)
-
-
 class CustomOpenAPISchemaGenerator(OpenAPISchemaGenerator):
 
     def get_schema(self, *args, **kwargs):
